/*	Justin Fiedler
	MyImage.cpp
	My own image widget.  Holds a TargaImage and a <last_width> of the border(used to cut back on loading).
*/

#include <iostream>
#include <FL/fl_draw.h>
#include "MyImage.h"

MyImage::MyImage(int x, int y, int w, int h, const char *label)
: Fl_Widget(x, y, w, h, label){
	image = NULL;
	last_width=0;
}

MyImage::~MyImage(){
	delete image;
}

//the overloaded draw function
void MyImage::draw(){
	// setup image
	static bool firstTime = true;
	if (firstTime)	{
		image = TargaImage::Load_Image("hasselhoff.tga");
	if (image == NULL)
		std::cerr << 	"Failed to load image." << std::endl;
	firstTime = false;
	}

	// draw the image
	if (image != NULL)
		fl_draw_image(image->data, 0, 0, image->width, image->height, 4);
}

//draws a border of <b_width> pixels arround the image
void MyImage::border(int b_width) {
	if(b_width != last_width){						//if the thickness doesnt change then dont do anything
		if (image == NULL || b_width < last_width)	//reload the image if current border width is less than last
			image = TargaImage::Load_Image("hasselhoff.tga");
		if (image == NULL)
			std::cerr << 	"Failed to load image." << std::endl;
		last_width = b_width;

		//loop through the image and replace image pixels with a green border of <b_width>;
		for(int x=0; x < image->width; x++){
			for(int y=0; y < image->height; y++) {
				if(x < b_width || y < b_width || x > image->width - b_width || y > image->height - b_width) {
					int index = (y * image->width + x) * 4; // Compute the index for this pixel
					unsigned char* pixel = image->data + index;				
						pixel[0] = 0;   // Change red to 0
						pixel[1] = 0;	// Change green to 0
						pixel[2] = 255;	// Change blue to 1
						pixel[3] = 255; // Change alpha to 1
				}
			}
		}
	}
}